@@ -423,6 +423,10 @@ class MainWindow(Adw.ApplicationWindow):
         self.filechooser.set_modal(True)
         self.filechooser.set_transient_for(self)
 
+        # / is the base path when the current file has not been saved
+        if self.current.base_path != "/":
+            self.filechooser.set_current_folder(Gio.File.new_for_path(self.current.base_path))
+
         title = self.current.title
         if not title.endswith(".md"):
             title += ".md"
@@ -546,18 +550,27 @@ class MainWindow(Adw.ApplicationWindow):
         except GLib.GError as error:
             helpers.show_error(self, str(error.message))
             LOGGER.warning(str(error.message))
+            self.new_document()
             return
 
         try:
             try:
                 self.current.encoding = 'UTF-8'
                 decoded = contents.decode(self.current.encoding)
-            except UnicodeDecodeError:
+            except UnicodeDecodeError as error:
                 self.current.encoding = chardet.detect(contents)['encoding']
+                if not self.current.encoding:
+                    raise error
                 decoded = contents.decode(self.current.encoding)
         except UnicodeDecodeError as error:
-            helpers.show_error(self, str(error.message))
-            LOGGER.warning(str(error.message))
+            helpers.show_error(
+                self,
+                _("Failed to detect encoding for file:\n"
+                "{file}\n\nThe error was:\n{err_msg}")
+                .format(file=gfile.get_path(),
+                        err_msg=str(error).encode().decode("unicode-escape")))
+            LOGGER.warning(str(error))
+            self.new_document()
             return
         else:
             self.textview.set_text(decoded)
